Overview: module code — textblob-de 0.4.3 documentation

# All modules for which code is available

- _pattern.text
- nltk.classify.decisiontree
- nltk.classify.maxent
- nltk.classify.naivebayes
- nltk.classify.positivenaivebayes
- textblob.base
- textblob.blob
- textblob.classifiers
- textblob.decorators
- textblob.exceptions
- textblob.formats
- textblob.mixins
- textblob_de.base
- textblob_de.blob
- textblob_de.np_extractors
- textblob_de.parsers
- textblob_de.sentiments
- textblob_de.taggers
- textblob_de.tokenizers